@extends('layouts.app')
@section('htmlheader_title')
	FTN Zones
@endsection

@section('content')
	<div class="row">
		<div class="col-12">
			<h2>About FTN Zones</h2>
			<p>In FTN network addresses, a zone is the 3rd dimension and used when a system supports 3D (or better) addressing, ie: <strong class="highlight">zone</strong>:net/node.point@domain.</p>
			<p>Zones are used with domains to uniquely identify a FTN network. Within an FTN network there can be multiple zones with the same domain.</p>
			<p>It is rare that a domain has multiple zones - unless it grows quite large. Zones can also be used to group systems into a common boundary.</p>
		</div>
	</div>

	<div class="row">
		<div class="col-6">
			<p>This system is aware of the following zones in each domain:</p>

			@if (\App\Models\Zone::count() == 0)
				@can('admin',(new \App\Models\Zone))
					<p>There are no zones setup, to <a href="{{ url('ftn/zone/addedit') }}">set up your first</a>.</p>
				@else
					<p class="pad">There are no zones - you need to ask an admin to create one for you.</p>
				@endcan
			@else
				@can('admin',(new \App\Models\Domain))
				<p>You can <a href="{{ url('ftn/zone/addedit') }}">Add New Zone</a>.</p>
				@endcan
				<table class="table monotable" id="zones">
					<thead>
					<tr>
						<th>Domain</th>
						<th>Zone</th>
						<th>Active</th>
						<th>Systems</th>
					</tr>
					</thead>

					<tbody>
					@foreach (\App\Models\Zone::orderBy('zone_id')->with(['domain','addresses'])->get() as $oo)
						<tr>
							<td>{{ $oo->domain->name }}</td>
							<td><a href="{{ url('ftn/zone/addedit',[$oo->id]) }}">{{ $oo->zone_id }}</a></td>
							<td>{{ $oo->active ? 'YES' : 'NO' }}</td>
							<td>{{ $oo->addresses->count() }}</td>
						</tr>
					@endforeach
					</tbody>
				</table>
			@endif
		</div>
	</div>
@endsection

@section('page-scripts')
{{--
	<link type="text/css" rel="stylesheet" href="https://cdn.datatables.net/1.10.25/css/jquery.dataTables.min.css" media="screen">
	<link type="text/css" rel="stylesheet" href="https://cdn.datatables.net/rowgroup/1.1.2/css/rowGroup.dataTables.min.css" media="screen">
--}}
	<link type="text/css" rel="stylesheet" href="https://cdn.datatables.net/1.10.25/css/dataTables.bootstrap5.min.css" media="screen" >
	<link type="text/css" rel="stylesheet" href="{{ asset('plugin/dataTables/dataTables.bootstrap5.css') }}" media="screen">

	<script type="text/javascript" src="https://cdn.datatables.net/1.10.25/js/jquery.dataTables.min.js"></script>
	<script type="text/javascript" src="https://cdn.datatables.net/rowgroup/1.1.2/js/dataTables.rowGroup.min.js"></script>
	<script type="text/javascript" src="https://cdn.datatables.net/1.10.25/js/dataTables.bootstrap5.min.js"></script>

	<script type="text/javascript">
		$(document).ready(function() {
			$('table tr').click(function() {
				var href = $(this).find("a").attr("href");
				if(href) {
					window.location = href;
				}
			});

			$('#zones').DataTable({
				paging: false,
				searching: true,
				rowGroup: {
					dataSrc: [0],
				},
				columnDefs: [
					{
						targets: [0],
						visible: false,
					},
				],
			});
		});
	</script>
@append
