<?php

use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

use App\Http\Controllers\{HomeController,DomainController,NodeController,SystemController,UserController,ZoneController};
use App\Http\Controllers\Auth\LoginController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Auth::routes([
	'login'         => true,
	'logout'        => true,
	'register'      => true,
	'reset'         => true,       // for resetting passwords
	'confirm'       => true,       // for additional password confirmations
	'verify'        => true,       // for email verification
]);
Route::get('logout',[LoginController::class,'logout']);

Route::redirect('/','about');
Route::view('about','about');

Route::middleware(['verified','activeuser'])->group(function () {
	Route::get('ftn/domain',[DomainController::class,'home']);
	Route::match(['get','post'],'ftn/domain/addedit/{o?}',[DomainController::class,'add_edit'])
		->where('o','[0-9]+');

	Route::get('ftn/node',[NodeController::class,'home']);
	Route::match(['get','post'],'ftn/node/addedit/{o?}',[NodeController::class,'add_edit'])
		->where('o','[0-9]+');

	Route::get('ftn/system',[SystemController::class,'home']);
	Route::match(['get','post'],'ftn/system/addedit/{o?}',[SystemController::class,'add_edit'])
		->where('o','[0-9]+');
	Route::post('ftn/system/addaddress/{o?}',[SystemController::class,'add_address'])
		->where('o','[0-9]+');

	Route::get('ftn/zone',[ZoneController::class,'home']);
	Route::match(['get','post'],'ftn/zone/addedit/{o?}',[ZoneController::class,'add_edit'])
		->where('o','[0-9]+');
});

Route::get('network/{o}',[HomeController::class,'network']);
Route::get('permissions',[HomeController::class,'permissions']);
Route::get('search',[HomeController::class,'search']);

Route::middleware(['auth','can:admin'])->group(function () {
	Route::match(['get','post'],'setup',[HomeController::class,'setup']);

	Route::get('user/list',[UserController::class,'home']);
	Route::match(['get','post'],'user/addedit/{o?}',[UserController::class,'add_edit'])
		->where('o','[0-9]+');
});